
<h1 style="margin-top:90px">Ͽ</h1>
<p>ԤȤʤ桼ϿƲ</p>
<p>桼̾˻ȤʸȾѤαѿѤΤҤ餬ʡʡǤ<br>
ޤʸʾĹɬפǤ<br/>
ѥɤϳǧΤϤƤ</p>

<?php CreateAdminFormlet::show() ?>
